=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-04-06 05:16:57 +0000
+++ bzrlib/builtins.py	2008-04-12 05:48:07 +0000
@@ -4435,7 +4435,7 @@
                      lightweight_checkout='Reconfigure to a lightweight'
                      ' checkout.',
                      standalone='Reconfigure to be standalone.',
-                     sharing='Reconfigure to use a shared repository.'),
+                     use_shared='Reconfigure to use a shared repository.'),
                      Option('bind-to', help='Branch to bind checkout to.',
                             type=str),
                      Option('force',
@@ -4457,8 +4457,8 @@
         elif target_type == 'lightweight-checkout':
             reconfiguration = reconfigure.Reconfigure.to_lightweight_checkout(
                 directory, bind_to)
-        elif target_type == 'sharing':
-            reconfiguration = reconfigure.Reconfigure.to_sharing(directory)
+        elif target_type == 'use-shared':
+            reconfiguration = reconfigure.Reconfigure.to_use_shared(directory)
         elif target_type == 'standalone':
             reconfiguration = reconfigure.Reconfigure.to_standalone(directory)
         reconfiguration.apply(force)

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2008-04-06 04:44:17 +0000
+++ bzrlib/errors.py	2008-04-12 05:48:07 +0000
@@ -2558,9 +2558,9 @@
     _fmt = "'%(display_url)s' is already a lightweight checkout."
 
 
-class AlreadySharing(BzrDirError):
+class AlreadyUsingShared(BzrDirError):
 
-    _fmt = "'%(display_url)s' is already sharing a repository."
+    _fmt = "'%(display_url)s' is already using a shared repository."
 
 
 class AlreadyStandalone(BzrDirError):

=== modified file 'bzrlib/reconfigure.py'
--- bzrlib/reconfigure.py	2008-04-06 04:44:17 +0000
+++ bzrlib/reconfigure.py	2008-04-12 05:48:07 +0000
@@ -123,19 +123,19 @@
         return reconfiguration
 
     @classmethod
-    def to_sharing(klass, bzrdir):
-        """Convert a standalone branch into a sharing branch"""
+    def to_use_shared(klass, bzrdir):
+        """Convert a standalone branch into a repository branch"""
         reconfiguration = klass(bzrdir)
-        reconfiguration._set_sharing(sharing=True)
+        reconfiguration._set_use_shared(use_shared=True)
         if not reconfiguration.changes_planned():
-            raise errors.AlreadySharing(bzrdir)
+            raise errors.AlreadyUsingShared(bzrdir)
         return reconfiguration
 
     @classmethod
     def to_standalone(klass, bzrdir):
-        """Convert a standalone branch into a sharing branch"""
+        """Convert a repository branch into a standalone branch"""
         reconfiguration = klass(bzrdir)
-        reconfiguration._set_sharing(sharing=False)
+        reconfiguration._set_use_shared(use_shared=False)
         if not reconfiguration.changes_planned():
             raise errors.AlreadyStandalone(bzrdir)
         return reconfiguration
@@ -180,10 +180,10 @@
         if want_tree and self.tree is None:
             self._create_tree = True
 
-    def _set_sharing(self, sharing=None):
-        if sharing is None:
+    def _set_use_shared(self, use_shared=None):
+        if use_shared is None:
             return
-        if sharing:
+        if use_shared:
             if self.local_repository is not None:
                 self._destroy_repository = True
         else:

=== modified file 'bzrlib/tests/blackbox/test_reconfigure.py'
--- bzrlib/tests/blackbox/test_reconfigure.py	2008-04-06 05:16:57 +0000
+++ bzrlib/tests/blackbox/test_reconfigure.py	2008-04-12 05:48:07 +0000
@@ -68,16 +68,16 @@
         checkout = branch.create_checkout('checkout')
         self.run_bzr('reconfigure --lightweight-checkout checkout')
 
-    def test_standalone_to_sharing(self):
+    def test_standalone_to_use_shared(self):
         self.build_tree(['repo/'])
         tree = self.make_branch_and_tree('repo/tree')
         repo = self.make_repository('repo', shared=True)
-        self.run_bzr('reconfigure --sharing', working_dir='repo/tree')
+        self.run_bzr('reconfigure --use-shared', working_dir='repo/tree')
         tree = workingtree.WorkingTree.open('repo/tree')
         self.assertNotEqual(tree.bzrdir.root_transport.base,
             tree.branch.repository.bzrdir.root_transport.base)
 
-    def test_sharing_to_standalone(self):
+    def test_use_shared_to_standalone(self):
         repo = self.make_repository('repo', shared=True)
         branch = bzrdir.BzrDir.create_branch_convenience('repo/tree')
         self.assertNotEqual(branch.bzrdir.root_transport.base,

=== modified file 'bzrlib/tests/test_reconfigure.py'
--- bzrlib/tests/test_reconfigure.py	2008-04-06 04:44:17 +0000
+++ bzrlib/tests/test_reconfigure.py	2008-04-12 05:48:07 +0000
@@ -287,31 +287,31 @@
         self.assertRaises(errors.NoRepositoryPresent,
                           repository.Repository.open, 'repo')
 
-    def test_standalone_to_sharing(self):
+    def test_standalone_to_use_shared(self):
         self.build_tree(['root/'])
         tree = self.make_branch_and_tree('root/tree')
         tree.commit('Hello', rev_id='hello-id')
         repo = self.make_repository('root', shared=True)
-        reconfiguration = reconfigure.Reconfigure.to_sharing(tree.bzrdir)
+        reconfiguration = reconfigure.Reconfigure.to_use_shared(tree.bzrdir)
         reconfiguration.apply()
         tree = workingtree.WorkingTree.open('root/tree')
         self.assertTrue(repo.has_same_location(tree.branch.repository))
         self.assertEqual('Hello', repo.get_revision('hello-id').message)
 
-    def make_sharing_tree(self):
+    def make_repository_tree(self):
         self.build_tree(['root/'])
         repo = self.make_repository('root', shared=True)
         tree = self.make_branch_and_tree('root/tree')
-        reconfigure.Reconfigure.to_sharing(tree.bzrdir).apply()
+        reconfigure.Reconfigure.to_use_shared(tree.bzrdir).apply()
         return workingtree.WorkingTree.open('root/tree')
 
-    def test_sharing_to_sharing(self):
-        tree = self.make_sharing_tree()
-        self.assertRaises(errors.AlreadySharing,
-                          reconfigure.Reconfigure.to_sharing, tree.bzrdir)
+    def test_use_shared_to_use_shared(self):
+        tree = self.make_repository_tree()
+        self.assertRaises(errors.AlreadyUsingShared,
+                          reconfigure.Reconfigure.to_use_shared, tree.bzrdir)
 
-    def test_sharing_to_standalone(self):
-        tree = self.make_sharing_tree()
+    def test_use_shared_to_standalone(self):
+        tree = self.make_repository_tree()
         tree.commit('Hello', rev_id='hello-id')
         reconfigure.Reconfigure.to_standalone(tree.bzrdir).apply()
         tree = workingtree.WorkingTree.open('root/tree')

